ConnectionManagerLayer

Struct ConnectionManagerLayer 

pub struct ConnectionManagerLayer<T, P, R> { /* private fields */ }
Layer which adds connection management and converts to an inner service which accepts ExecuteRequest from an outer service which accepts http::Request.

Implementations

Source

impl<T, P, R> ConnectionManagerLayer<T, P, R>

pub fn new(transport: T, protocol: P) -> Self

Layer for connection pooling.

pub fn with_manager(self, manager: ConnectionManagerConfig) -> Self

Set the connection manager configuration.

pub fn with_optional_manager( self, manager: Option<ConnectionManagerConfig>, ) -> Self

Set the connection manager configuration to an optional value.

pub fn without_pool(self) -> Self

Disable connection management.